StandardPage class abstract

Implementers

Constructors

StandardPage([InitData? args])

Properties

hashCode → int
The hash code for this object.
no setterinherited
page ↔ StatefulWidget
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getActions() → Set<String?>
getConstructorArgs() → dynamic
getData() → dynamic
getPage() → StatefulWidget
getPageCallBackForAction() → dynamic
getPageContext() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited