StandardScreenResponse class

Annotations

Constructors

StandardScreenResponse()
StandardScreenResponse.fromJson(Map<String, dynamic> json)
factory

Properties

componentStype ↔ String
getter/setter pair
dataStore ↔ Map<String, dynamic>?
getter/setter pair
footers ↔ Map<String, dynamic>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, dynamic>?
getter/setter pair
pageState ↔ Map<String, dynamic>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair
widgets ↔ List<StandardPageResponseWidgets>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited