UikIconTextProps class

Inheritance

Constructors

UikIconTextProps()
UikIconTextProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction
getter/setter pair
bottomMargin ↔ double
getter/setter pair
distance ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ Widget?
getter/setter pair
id ↔ String
getter/setter pair
leftMargin ↔ double
getter/setter pair
rightMargin ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ Widget
getter/setter pair
topMargin ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited