UikImageProps class

Inheritance
Annotations

Constructors

UikImageProps()
UikImageProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction?
getter/setter pair
bottomLeftRadius ↔ double
getter/setter pair
bottomMargin ↔ double
getter/setter pair
bottomRightRadius ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
id ↔ String
getter/setter pair
leftMargin ↔ double
getter/setter pair
rightMargin ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeftRadius ↔ double
getter/setter pair
topMargin ↔ double
getter/setter pair
topRightRadius ↔ double
getter/setter pair
url ↔ String
getter/setter pair
width ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited