UikListViewProps class

Inheritance

Constructors

UikListViewProps()
UikListViewProps.fromJson(Map<String, dynamic> json)
factory

Properties

color ↔ Color?
getter/setter pair
direction ↔ Axis
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
horizontalPadding ↔ double
getter/setter pair
id ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalPadding ↔ double
getter/setter pair
widgets ↔ List<Widget>
getter/setter pair
width ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited