UikPageControlProps class

Inheritance
Annotations

Constructors

UikPageControlProps()
UikPageControlProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction
getter/setter pair
activeDotColor ↔ Color
getter/setter pair
backgroundColor ↔ Color
getter/setter pair
contentHeight ↔ double
getter/setter pair
contentWidth ↔ double
getter/setter pair
dotColor ↔ Color
getter/setter pair
dotHeight ↔ double
getter/setter pair
dotRadius ↔ double
getter/setter pair
dotWidth ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isBackground ↔ bool
getter/setter pair
list ↔ List<Widget>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited