UikReviewProps class

Inheritance
Annotations

Constructors

UikReviewProps()
UikReviewProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction
getter/setter pair
avatar ↔ Widget?
getter/setter pair
datetext ↔ Widget?
getter/setter pair
dectext ↔ Widget?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ Widget?
getter/setter pair
id ↔ String
getter/setter pair
image ↔ Widget?
getter/setter pair
nametext ↔ Widget?
getter/setter pair
rating ↔ Widget?
getter/setter pair
review ↔ Widget?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited