UikSortPageProps class

Inheritance
Annotations

Constructors

UikSortPageProps()
UikSortPageProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction
getter/setter pair
filterButton ↔ Widget
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheet ↔ Widget?
getter/setter pair
sortButton ↔ Widget
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited