UikTextAreaProps class

Inheritance
Annotations

Constructors

UikTextAreaProps()
UikTextAreaProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction
getter/setter pair
backgroundColor ↔ Color?
getter/setter pair
borderColor ↔ Color?
getter/setter pair
corner ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
id ↔ String
getter/setter pair
isBorder ↔ bool
getter/setter pair
isLabel ↔ bool
getter/setter pair
label ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
transparency ↔ bool
getter/setter pair
width ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited