UikTextFieldProps class

Inheritance
Annotations

Constructors

UikTextFieldProps()
UikTextFieldProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction
getter/setter pair
bottomMargin ↔ double
getter/setter pair
description ↔ String
getter/setter pair
error ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
hintText ↔ String
getter/setter pair
id ↔ String
getter/setter pair
initialValue ↔ String?
getter/setter pair
labelText ↔ String?
getter/setter pair
leftElement ↔ Widget?
getter/setter pair
leftMargin ↔ double
getter/setter pair
rightElement ↔ Widget?
getter/setter pair
rightMargin ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topMargin ↔ double
getter/setter pair
width ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited