UikTextRadioButtonProps class

Inheritance
Annotations

Constructors

UikTextRadioButtonProps({double marginBottom = 0.0, double marginLeft = 0.0, double marginRight = 0.0, double marginTop = 0.0})
UikTextRadioButtonProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
marginBottom ↔ double
getter/setter pair
marginLeft ↔ double
getter/setter pair
marginRight ↔ double
getter/setter pair
marginTop ↔ double
getter/setter pair
radiobutton ↔ Widget?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ Widget?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited