UikThreeColumnTileProps class

Inheritance
Annotations

Constructors

UikThreeColumnTileProps()
UikThreeColumnTileProps.fromJson(Map<String, dynamic> json)
factory

Properties

bottomMargin ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
leftMargin ↔ double
getter/setter pair
rightMargin ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text1 ↔ Widget
getter/setter pair
text2 ↔ Widget
getter/setter pair
text3 ↔ Widget
getter/setter pair
topMargin ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited