UikThreeComponentRowProps class

Inheritance
Annotations

Constructors

UikThreeComponentRowProps({double marginBottom = 0.0, double marginLeft = 0.0, double marginRight = 0.0, double marginTop = 0.0})
UikThreeComponentRowProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction
getter/setter pair
endtext ↔ Widget?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ Widget?
getter/setter pair
id ↔ String
getter/setter pair
marginBottom ↔ double
getter/setter pair
marginLeft ↔ double
getter/setter pair
marginRight ↔ double
getter/setter pair
marginTop ↔ double
getter/setter pair
middletext ↔ Widget?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited