UikTwoComponentRowProps class

Inheritance
Annotations

Constructors

UikTwoComponentRowProps()
UikTwoComponentRowProps.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ UikAction
getter/setter pair
bgcolor ↔ Color
getter/setter pair
borderRadius ↔ double
getter/setter pair
crossAxisAlignment ↔ CrossAxisAlignment
getter/setter pair
enablePadding ↔ bool
getter/setter pair
firstComponent ↔ Widget?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
id ↔ String
getter/setter pair
mainAxisAlignment ↔ MainAxisAlignment
getter/setter pair
marginBottom ↔ double
getter/setter pair
marginLeft ↔ double
getter/setter pair
marginRight ↔ double
getter/setter pair
marginTop ↔ double
getter/setter pair
opacity ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondComponent ↔ Widget?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited